=======
SVBench
=======

SVBench is a library for benchmarking variant calls vs a reference dataset.


Installation
------------
Install using::

    pip install svbench

Or::

    pip install -r requirements.txt; pip install .

Requires Python>=3.6, packages needed are listed in requirements.txt.


Usage
-----
For a general tutorial on using the API see the ipython notebook; `svbench_tutorial.ipynb`
